@@ -27,7 +27,11 @@
 #include <fcntl.h>
 
 #include <gtk/gtk.h>
+#include <libxfce4ui/libxfce4ui.h>
+
+#if !LIBXFCE4UI_CHECK_VERSION(4, 21, 0)
 #include <exo/exo.h>
+#endif
 
 #include "xfburn-global.h"
 #include "xfburn-utils.h"
@@ -219,8 +223,11 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   priv->burn_button = xfce_gtk_button_new_mixed ("stock_xfburn", _("_Burn image"));
   gtk_widget_show (priv->burn_button);
   g_signal_connect (G_OBJECT (priv->burn_button), "clicked", G_CALLBACK (cb_clicked_ok), obj);
-  gtk_container_add (GTK_CONTAINER( exo_gtk_dialog_get_action_area (GTK_DIALOG (obj))), priv->burn_button);
-  //gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_OK);
+#if LIBXFCE4UI_CHECK_VERSION(4, 21, 0)
+  gtk_container_add (GTK_CONTAINER(xfce_gtk_dialog_get_action_area (GTK_DIALOG (obj))), priv->burn_button);
+#else
+  gtk_container_add (GTK_CONTAINER(exo_gtk_dialog_get_action_area (GTK_DIALOG (obj))), priv->burn_button);
+#endif
   gtk_widget_set_can_default (priv->burn_button, TRUE);
   gtk_widget_grab_focus (priv->burn_button);
   gtk_widget_grab_default (priv->burn_button);
