@@ -39,7 +39,9 @@
 
 #include <gio/gio.h>
 
+#if !LIBXFCE4UI_CHECK_VERSION(4, 21, 0)
 #include <exo/exo.h>
+#endif
 
 #include <libisofs.h>
 #include <glib/gstdio.h>
@@ -102,11 +104,6 @@ typedef struct {
 static void composition_interface_init (XfburnCompositionInterface *composition, gpointer iface_data);
 static void xfburn_data_composition_finalize (GObject * object);
 
-static void show_custom_controls (XfburnComposition *composition);
-static void hide_custom_controls (XfburnComposition *composition);
-static void load_from_file (XfburnComposition *composition, const gchar *file);
-static void save_to_file (XfburnComposition *composition);
-
 static gint directory_tree_sortfunc (GtkTreeModel * model, GtkTreeIter * a, GtkTreeIter * b, gpointer user_data);
 
 static void set_default_name (XfburnDataComposition * dc);
@@ -224,10 +221,6 @@ xfburn_data_composition_class_init (XfburnDataCompositionClass * klass)
 static void
 composition_interface_init (XfburnCompositionInterface *composition, gpointer iface_data)
 {
-  composition->show_custom_controls = show_custom_controls;
-  composition->hide_custom_controls = hide_custom_controls;
-  composition->load = load_from_file;
-  composition->save = save_to_file;
 }
 
 static void
@@ -287,21 +280,6 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
   gtk_widget_show (hbox_toolbar);
 
   /* toolbar */
-/*  model_toolbar = exo_toolbars_model_new ();
-  exo_toolbars_model_set_actions (model_toolbar, (gchar **) toolbar_actions, G_N_ELEMENTS (toolbar_actions));
-  toolbar_position = exo_toolbars_model_add_toolbar (model_toolbar, -1, "content-toolbar");
-  exo_toolbars_model_set_style (model_toolbar, GTK_TOOLBAR_BOTH, toolbar_position);
-
-  exo_toolbars_model_add_item (model_toolbar, toolbar_position, -1, "add-file", EXO_TOOLBARS_ITEM_TYPE);
-  exo_toolbars_model_add_item (model_toolbar, toolbar_position, -1, "create-dir", EXO_TOOLBARS_ITEM_TYPE);
-  exo_toolbars_model_add_separator (model_toolbar, toolbar_position, -1);
-  exo_toolbars_model_add_item (model_toolbar, toolbar_position, -1, "remove-file", EXO_TOOLBARS_ITEM_TYPE);
-  exo_toolbars_model_add_item (model_toolbar, toolbar_position, -1, "clear", EXO_TOOLBARS_ITEM_TYPE);
-  //exo_toolbars_model_add_separator (model_toolbar, toolbar_position, -1);
-  //exo_toolbars_model_add_item (model_toolbar, toolbar_position, -1, "import-session", EXO_TOOLBARS_ITEM_TYPE);
-
-  priv->toolbar = exo_toolbars_view_new_with_model (priv->ui_manager, model_toolbar);
-*/
   priv->toolbar = gtk_toolbar_new ();
   gtk_toolbar_set_style(GTK_TOOLBAR (priv->toolbar), GTK_TOOLBAR_BOTH);
   gtk_widget_insert_action_group (priv->toolbar, "win", G_ACTION_GROUP (priv->action_group));
@@ -345,7 +323,11 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
   gtk_widget_show (scrolled_window);
   gtk_box_pack_start (GTK_BOX (composition), scrolled_window, TRUE, TRUE, 0);
 
+#if LIBXFCE4UI_CHECK_VERSION(4, 21, 0)
+  priv->content = xfce_tree_view_new ();
+#else
   priv->content = exo_tree_view_new ();
+#endif
   model = gtk_tree_store_new (DATA_COMPOSITION_N_COLUMNS, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING,
                               G_TYPE_UINT64, G_TYPE_STRING, G_TYPE_UINT);
   priv->model = model;
@@ -354,7 +336,6 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
                                    directory_tree_sortfunc, NULL, NULL);
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), DATA_COMPOSITION_COLUMN_CONTENT, GTK_SORT_ASCENDING);
   gtk_tree_view_set_model (GTK_TREE_VIEW (priv->content), GTK_TREE_MODEL (model));
-  // gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (priv->content), TRUE);
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->content));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
   gtk_widget_show (priv->content);
@@ -455,18 +436,6 @@ xfburn_data_composition_finalize (GObject * object)
 /*************/
 /* internals */
 /*************/
-static void
-show_custom_controls (XfburnComposition *composition)
-{
-  DBG ("show");
-}
-
-static void
-hide_custom_controls (XfburnComposition *composition)
-{
-  DBG ("hide");
-}
-
 static void
 cb_begin_burn (XfburnDataDiscUsage * du, XfburnDataComposition * dc)
 {
@@ -1036,19 +1005,6 @@ static void
 set_modified (XfburnDataCompositionPrivate *priv)
 {
   if (!(priv->modified)) {
-    /*
-    XfburnMainWindow *mainwin;
-    GtkUIManager *ui_manager;
-    GtkActionGroup *action_group;
-
-    mainwin = xfburn_main_window_get_instance ();
-    ui_manager = xfburn_main_window_get_ui_manager (mainwin);
-
-    action_group = (GtkActionGroup *) gtk_ui_manager_get_action_groups (ui_manager)->data;
-
-    action = gtk_action_group_get_action (action_group, "save-composition");
-    gtk_action_set_sensitive (GTK_ACTION (action), TRUE);
-    */
     priv->modified = TRUE;
   }
 }
@@ -1994,259 +1950,6 @@ generate_iso_image (XfburnDataComposition * dc)
   return image;
 }
 
-/****************/
-/* loading code */
-/****************/
-typedef struct
-{
-  gboolean started;
-  XfburnDataComposition *dc;
-  GQueue *queue_iter;
-} LoadParserStruct;
-
-/*
-static gint
-_find_attribute (const gchar ** attribute_names, const gchar * attr)
-{
-  gint i;
-
-  for (i = 0; attribute_names[i]; i++) {
-    if (!strcmp (attribute_names[i], attr))
-      return i;
-  }
-
-  return -1;
-}
-*/
-
-G_GNUC_NORETURN
-static void
-load_composition_start (GMarkupParseContext * context, const gchar * element_name,
-                        const gchar ** attribute_names, const gchar ** attribute_values,
-                        gpointer data, GError ** error)
-{
-  g_error ("This method needs to get fixed, and does not work right now!");
-/*
-  LoadParserStruct * parserinfo = (LoadParserStruct *) data;
-  XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (parserinfo->dc);
-
-
-  if (!(parserinfo->started) && !strcmp (element_name, "xfburn-composition"))
-    parserinfo->started = TRUE;
-  else if (!(parserinfo->started))
-    return;
-
-  if (!strcmp (element_name, "file")) {
-    int i, j;
-
-    if ((i = _find_attribute (attribute_names, "name")) != -1 &&
-        (j = _find_attribute (attribute_names, "source")) != -1) {
-      //GtkTreeIter iter;
-      GtkTreeIter *parent;
-      GtkTreeModel *model;
-
-      model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->content));
-      parent = g_queue_peek_head (parserinfo->queue_iter);
-
-      add_file_to_list_with_name (attribute_values[i], parserinfo->dc, model, attribute_values[j], &iter,
-                                  parent, GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
-    }
-  } else if (!strcmp (element_name, "directory")) {
-    int i, j;
-
-    if ((i = _find_attribute (attribute_names, "name")) != -1 &&
-        (j = _find_attribute (attribute_names, "source")) != -1) {
-      //GtkTreeIter iter;
-      GtkTreeModel *model;
-
-      model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->content));
-
-      //add_directory_to_list (attribute_values[i], parserinfo->dc, model, attribute_values[j], &iter, parent);
-    }
-  }
-  */
-}
-
-static void
-load_composition_end (GMarkupParseContext * context, const gchar * element_name, gpointer user_data, GError ** error)
-{
-  LoadParserStruct *parserinfo = (LoadParserStruct *) user_data;
-
-  if (!parserinfo->started)
-    return;
-
-  if (!strcmp (element_name, "xfburn-composition"))
-    parserinfo->started = FALSE;
-
-  if (!strcmp (element_name, "directory"))
-    parserinfo->queue_iter = g_queue_pop_head (parserinfo->queue_iter);
-}
-
-static void
-load_from_file (XfburnComposition * composition, const gchar * filename)
-{
-  gchar *file_contents = NULL;
-  GMarkupParseContext *gpcontext = NULL;
-  struct stat st;
-  LoadParserStruct parserinfo;
-  GMarkupParser gmparser = {
-    load_composition_start, load_composition_end, NULL, NULL, NULL
-  };
-  GError *err = NULL;
-#ifdef HAVE_MMAP
-  gint fd = -1;
-  void *maddr = NULL;
-#endif
-  g_return_if_fail (filename != NULL);
-  if (stat (filename, &st) < 0) {
-    g_warning ("Unable to open %s", filename);
-    goto cleanup;
-  }
-
-#ifdef HAVE_MMAP
-  fd = open (filename, O_RDONLY, 0);
-  if (fd < 0)
-    goto cleanup;
-  maddr = mmap (NULL, st.st_size, PROT_READ, MAP_FILE | MAP_SHARED, fd, 0);
-  if (maddr)
-    file_contents = maddr;
-#endif
-  if (!file_contents && !g_file_get_contents (filename, &file_contents, NULL, &err)) {
-    if (err) {
-      g_warning ("Unable to read file '%s' (%d): %s", filename, err->code, err->message);
-      g_error_free (err);
-    }
-    goto cleanup;
-  }
-
-  parserinfo.started = FALSE;
-  parserinfo.dc = XFBURN_DATA_COMPOSITION (composition);
-  parserinfo.queue_iter = g_queue_new ();
-  gpcontext = g_markup_parse_context_new (&gmparser, 0, &parserinfo, NULL);
-  if (!g_markup_parse_context_parse (gpcontext, file_contents, st.st_size, &err)) {
-    g_warning ("Error parsing composition (%d): %s", err->code, err->message);
-    g_error_free (err);
-    goto cleanup;
-  }
-
-  if (g_markup_parse_context_end_parse (gpcontext, NULL)) {
-    DBG ("parsed");
-  }
-
-  g_queue_free (parserinfo.queue_iter);
-
-cleanup:
-  if (gpcontext)
-    g_markup_parse_context_free (gpcontext);
-#ifdef HAVE_MMAP
-  if (maddr) {
-    munmap (maddr, st.st_size);
-    file_contents = NULL;
-  }
-  if (fd > -1)
-    close (fd);
-#endif
-  if (file_contents)
-    g_free (file_contents);
-}
-
-
-/***************/
-/* saving code */
-/***************/
-typedef struct
-{
-  FILE *file_content;
-  gint last_depth;
-} CompositionSaveInfo;
-
-static gboolean
-foreach_save (GtkTreeModel * model, GtkTreePath * path, GtkTreeIter * iter, CompositionSaveInfo *info)
-{
-  gchar *space = NULL;
-  gint i;
-  gchar *name = NULL;
-  gchar *source_path = NULL;
-  DataCompositionEntryType type;
-
-  space = g_strnfill (gtk_tree_path_get_depth (path), '\t');
-
-  for (i = info->last_depth; i > gtk_tree_path_get_depth (path); i--) {
-    gchar *space2 = NULL;
-
-    space2 = g_strnfill (i - 1, '\t');
-    fprintf (info->file_content, "%s</directory>\n", space2);
-
-    g_free (space2);
-  }
-
-  gtk_tree_model_get (model, iter, DATA_COMPOSITION_COLUMN_CONTENT, &name,
-                      DATA_COMPOSITION_COLUMN_PATH, &source_path,
-                      DATA_COMPOSITION_COLUMN_TYPE, &type, -1);
-
-  fprintf (info->file_content, "%s", space);
-  switch (type) {
-  case DATA_COMPOSITION_TYPE_FILE:
-    fprintf (info->file_content, "<file name=\"%s\" source=\"%s\" />\n", name, source_path);
-    break;
-  case DATA_COMPOSITION_TYPE_DIRECTORY:
-    fprintf (info->file_content, "<directory name=\"%s\" source=\"%s\"", name, source_path);
-
-    if (gtk_tree_model_iter_has_child (model, iter))
-      fprintf (info->file_content, ">\n");
-    else
-      fprintf (info->file_content, "/>\n");
-
-    break;
-  }
-
-
-  info->last_depth = gtk_tree_path_get_depth (path);
-
-  g_free (space);
-  g_free (name);
-  g_free (source_path);
-
-  return FALSE;
-}
-
-static void
-save_to_file (XfburnComposition * composition)
-{
-  XfburnDataCompositionPrivate *priv = XFBURN_DATA_COMPOSITION_GET_PRIVATE (composition);
-  FILE *file_content;
-  GtkTreeModel *model;
-  CompositionSaveInfo info;
-  gint i;
-
-  if (!(priv->filename)) {
-    priv->filename = g_strdup ("/tmp/gna");
-
-    g_signal_emit_by_name (G_OBJECT (composition), "name-changed", priv->filename);
-  }
-
-  file_content = fopen (priv->filename, "w+");
-  fprintf (file_content, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n\n");
-  fprintf (file_content, "<xfburn-composition version=\"0.1\">\n");
-
-  model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->content));
-  info.file_content = file_content;
-  info.last_depth = 0;
-  gtk_tree_model_foreach (model, (GtkTreeModelForeachFunc) foreach_save, &info);
-
-  for (i = info.last_depth; i > 1; i--) {
-    gchar *space2 = NULL;
-
-    space2 = g_strnfill (i - 1, '\t');
-    fprintf (info.file_content, "%s</directory>\n", space2);
-
-    g_free (space2);
-  }
-
-  fprintf (file_content, "</xfburn-composition>\n");
-  fclose (file_content);
-}
-
 /******************/
 /* public methods */
 /******************/
