@@ -29,8 +29,6 @@
 
 #include <gio/gio.h>
 
-#include <exo/exo.h>
-
 #include "xfburn-directory-browser.h"
 #include "xfburn-data-composition.h"
 #include "xfburn-utils.h"
@@ -54,9 +52,9 @@ static const gchar *DIRECTORY = N_("Folder");
 /********************************/
 /* XfburnDirectoryBrowser class */
 /********************************/
-static ExoTreeViewClass *parent_class = NULL;
+static GtkTreeViewClass *parent_class = NULL;
 
-G_DEFINE_TYPE_WITH_PRIVATE(XfburnDirectoryBrowser, xfburn_directory_browser, EXO_TYPE_TREE_VIEW);
+G_DEFINE_TYPE_WITH_PRIVATE(XfburnDirectoryBrowser, xfburn_directory_browser, GTK_TYPE_TREE_VIEW);
 
 static void
 xfburn_directory_browser_finalize (GObject * object)
@@ -94,7 +92,6 @@ xfburn_directory_browser_init (XfburnDirectoryBrowser * browser)
                                    directory_tree_sortfunc, NULL, NULL);
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), DIRECTORY_BROWSER_COLUMN_FILE, GTK_SORT_ASCENDING);
   gtk_tree_view_set_model (GTK_TREE_VIEW (browser), GTK_TREE_MODEL (model));
-  // gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (browser), TRUE);
 
   column_file = gtk_tree_view_column_new ();
   gtk_tree_view_column_set_title (column_file, _("File"));
@@ -244,12 +241,6 @@ xfburn_directory_browser_load_path (XfburnDirectoryBrowser * browser, const gcha
     }
 
     full_path = g_build_filename (path, dir_entry, NULL);
-#if 0
-    if (g_file_test (full_path, G_FILE_TEST_IS_SYMLINK)) {
-      g_free (full_path);
-      continue;
-    }
-#endif
 
     if (stat (full_path, &s) == 0) {
       gchar *humansize;
