@@ -21,7 +21,6 @@
 #endif /* !HAVE_CONFIG_H */
 
 #include <libxfce4ui/libxfce4ui.h>
-#include <exo/exo.h>
 
 #include "xfburn-preferences-dialog.h"
 #include "xfburn-device-list.h"
@@ -44,9 +43,6 @@ typedef struct
 
   GtkWidget *treeview_devices;
   GtkWidget *button_scan;
-#if 0
-  GtkWidget *check_empty_speed_list;
-#endif
   GtkWidget *scale_fifo;
 } XfburnPreferencesDialogPrivate;
 
@@ -123,23 +119,9 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (box, hbox, TRUE, TRUE, 0);
   gtk_widget_show (hbox);
-/*  // because exo icon bar isn't available disabling the side panel scrolled window
-  scrolled_window = gtk_scrolled_window_new (NULL, NULL);
-  g_object_set (G_OBJECT (scrolled_window),
-                "hscrollbar-policy", GTK_POLICY_NEVER,
-                "shadow-type", GTK_SHADOW_IN,
-                "vscrollbar-policy", GTK_POLICY_NEVER,
-                NULL);
-  gtk_box_pack_start (GTK_BOX (hbox), scrolled_window, FALSE, FALSE, 0);
-  gtk_widget_show (scrolled_window);
-*/
+
   /* icon bar */
   icon_store = gtk_list_store_new (SETTINGS_LIST_N_COLUMNS, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_INT);
-  // priv->icon_bar = exo_icon_view_new_with_model (GTK_TREE_MODEL (icon_store));
-  // g_object_set_property (G_OBJECT (priv->icon_bar), "pixbuf-column", &pb_col);
-  // g_object_set_property (G_OBJECT (priv->icon_bar), "text-column", &tx_col);
-  // gtk_container_add (GTK_CONTAINER (scrolled_window), priv->icon_bar);
-  // gtk_widget_show (priv->icon_bar);
 
   /* notebook */
   priv->notebook = gtk_notebook_new ();
@@ -233,7 +215,6 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
                               G_TYPE_BOOLEAN);
   priv->treeview_devices = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store), DEVICE_LIST_COLUMN_NAME, GTK_SORT_ASCENDING);
-  // gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (priv->treeview_devices), TRUE);
   gtk_widget_show (priv->treeview_devices);
   gtk_container_add (GTK_CONTAINER (scrolled_window), priv->treeview_devices);
   g_object_unref (store);
@@ -298,16 +279,6 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   if (icon)
     g_object_unref (G_OBJECT (icon));
 
-//  exo_mutual_binding_new (G_OBJECT (priv->notebook), "page", G_OBJECT (priv->icon_bar), "active");
-
-
-  /* below the device list */
-#if 0
-  priv->check_empty_speed_list = gtk_check_button_new_with_mnemonic (_("Show warning on _empty speed list"));
-  gtk_box_pack_start (GTK_BOX (vbox2), priv->check_empty_speed_list, FALSE, FALSE, BORDER);
-  gtk_widget_show (priv->check_empty_speed_list);
-#endif
-
   /* fifo */
   vbox3 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_widget_show (vbox3);
@@ -369,10 +340,6 @@ xfburn_preferences_dialog_load_settings (XfburnPreferencesDialog * dialog)
                                 xfburn_settings_get_boolean ("show-hidden-files", FALSE));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->check_show_human_readable),
                                 xfburn_settings_get_boolean ("human-readable-units", TRUE));
-#if 0
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->check_empty_speed_list),
-                                xfburn_settings_get_boolean ("show-empty-speed-list-notice", TRUE));
-#endif
   gtk_range_set_value (GTK_RANGE (priv->scale_fifo),
                                 (double) xfburn_settings_get_int ("fifo-size", FIFO_DEFAULT_SIZE));
 }
@@ -393,10 +360,6 @@ xfburn_preferences_dialog_save_settings (XfburnPreferencesDialog *dialog)
                                gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_show_hidden)));
   xfburn_settings_set_boolean ("human-readable-units",
                                gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_show_human_readable)));
-#if 0
-  xfburn_settings_set_boolean ("show-empty-speed-list-notice",
-                               gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_empty_speed_list)));
-#endif
   xfburn_settings_set_int ("fifo-size",
                                ((((int) gtk_range_get_value (GTK_RANGE (priv->scale_fifo)) / 32) * 32))); /* this should round to multiples of 1024 */
 }
